==> customized-facade-1.0.7-20210622.112454-4-sources.jar: com/bizvane/customized/facade/models/vo/MemberCaseDetailVo.java <==
package com.bizvane.customized.facade.models.vo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Date;

/**
 * @Author: LiJC
 * @CreateTime: 2019/8/07.
 */
@Data
public class MemberCaseDetailVo {

    @ApiModelProperty(name = "Id", value = "病历ID")
    private Long id;

    @ApiModelProperty(name = "name",value = "姓名")
    private String name;

    @ApiModelProperty(name = "phone",value = "手机号")
    private String phone;

    @ApiModelProperty(name = "sex",value = "性别")
    private String sex;

    @ApiModelProperty(name = "age",value = "年龄")
    private String age;

    @ApiModelProperty(name = "card",value = "身份证")
    private String card;

    @ApiModelProperty(name = "job",value = "职业")
    private String job;

    @ApiModelProperty(name = "address",value = "地址")
    private String address;

    @ApiModelProperty(name = "rightEyeVision",value = "右眼戴镜视力")
    private String rightEyeVision;

    @ApiModelProperty(name = "leftEyeVision",value = "左眼戴镜视力")
    private String leftEyeVision;

    @ApiModelProperty(name = "rightLyEyeVisionJ",value = "右眼裸眼视力近")
    private String rightLyEyeVisionJ;

    @ApiModelProperty(name = "rightLyEyeVisionY",value = "右眼裸眼视力远")
    private String rightLyEyeVisionY;

    @ApiModelProperty(name = "leftLyEyeVisionJ",value = "左眼裸眼视力近")
    private String leftLyEyeVisionJ;

    @ApiModelProperty(name = "leftLyEyeVisionY",value = "左眼裸眼视力远")
    private String leftLyEyeVisionY;

    @ApiModelProperty(name = "rightEyePressure",value = "右眼眼压")
    private String rightEyePressure;

    @ApiModelProperty(name = "leftEyePressure",value = "左眼眼压")
    private String leftEyePressure;

    @ApiModelProperty(name = "rightPupilDiameterPhotopic",value = "右眼瞳孔直径明视")
    private String rightPupilDiameterPhotopic;

    @ApiModelProperty(name = "leftPupilDiameterPhotopic",value = "左眼瞳孔直径明视")
    private String leftPupilDiameterPhotopic;

    @ApiModelProperty(name = "rightPupilDiameterAmblyopia",value = "右眼瞳孔直径暗视")
    private String rightPupilDiameterAmblyopia;

    @ApiModelProperty(name = "leftPupilDiameterAmblyopia",value = "左眼瞳孔直径暗视")
    private String leftPupilDiameterAmblyopia;

    @ApiModelProperty(name = "rightEyePosition",value = "右眼眼位")
    private String rightEyePosition;

    @ApiModelProperty(name = "rightEyePositionValue",value = "右眼眼位数值")
    private String rightEyePositionValue;

    @ApiModelProperty(name = "leftEyePosition",value = "左眼眼位")
    private String leftEyePosition;

    @ApiModelProperty(name = "leftEyePositionValue",value = "左眼眼位数值")
    private String leftEyePositionValue;

    @ApiModelProperty(name = "rightEyeDiopterDs",value = "右眼复光度数DS")
    private String rightEyeDiopterDs;

    @ApiModelProperty(name = "rightEyeDiopterDc",value = "右眼复光度数DC")
    private String rightEyeDiopterDc;

    @ApiModelProperty(name = "rightEyeComplexPowerAxis",value = "右眼复光度数轴位")
    private String rightEyeComplexPowerAxis;

    @ApiModelProperty(name = "rightEyeDiopterCorrectedVisualAcuity",value = "右眼复光度数矫正视力")
    private String rightEyeDiopterCorrectedVisualAcuity;

    @ApiModelProperty(name = "leftEyeDiopterDs",value = "左眼复光度数DS")
    private String leftEyeDiopterDs;

    @ApiModelProperty(name = "leftEyeDiopterDc",value = "左眼复光度数DC")
    private String leftEyeDiopterDc;

    @ApiModelProperty(name = "leftEyeComplexPowerAxis",value = "左眼复光度数轴位")
    private String leftEyeComplexPowerAxis;

    @ApiModelProperty(name = "leftEyeDiopterCorrectedVisualAcuity",value = "左眼复光度数矫正视力")
    private String leftEyeDiopterCorrectedVisualAcuity;

    @ApiModelProperty(name = "rightEyeCt",value = "右眼术前角膜厚度")
    private String rightEyeCt;

    @ApiModelProperty(name = "leftEyeCt",value = "左眼术前角膜厚度")
    private String leftEyeCt;

    @ApiModelProperty(name = "rightEyeDegrees",value = "右眼验光度数")
    private String rightEyeDegrees;

    @ApiModelProperty(name = "leftEyeDegrees",value = "左眼验光度数")
    private String leftEyeDegrees;

    @ApiModelProperty(name = "rightEyeK1",value = "右眼角膜曲率K1")
    private String rightEyeK1;

    @ApiModelProperty(name = "rightEyeZwK1",value = "右眼角膜曲率K1轴位")
    private String rightEyeZwK1;

    @ApiModelProperty(name = "leftEyeK1",value = "左眼角膜曲率K1")
    private String leftEyeK1;

    @ApiModelProperty(name = "leftEyeZwK1",value = "左眼角膜曲率K1轴位")
    private String leftEyeZwK1;

    @ApiModelProperty(name = "rightEyeK2",value = "右眼角膜曲率K2")
    private String rightEyeK2;

    @ApiModelProperty(name = "rightEyeZwK2",value = "右眼角膜曲率K2轴位")
    private String rightEyeZwK2;

    @ApiModelProperty(name = "leftEyeK2",value = "左眼角膜曲率K2")
    private String leftEyeK2;

    @ApiModelProperty(name = "leftEyeZwK2",value = "左眼角膜曲率K2轴位")
    private String leftEyeZwK2;

    @ApiModelProperty(name = "rightEyeSurgery",value = "右眼手术方式")
    private String rightEyeSurgery;

    @ApiModelProperty(name = "leftEyeSurgery",value = "左眼手术方式")
    private String leftEyeSurgery;

    @ApiModelProperty(name = "rightEyeSsDate",value = "右眼手术日期")
    private String rightEyeSsDate;

    @ApiModelProperty(name = "leftEyeSsDate",value = "左眼手术日期")
    private String leftEyeSsDate;

    @ApiModelProperty(name = "fcDate1",value = "第一次复查时间")
    private String fcDate1;

    @ApiModelProperty(name = "fcDate11",value = "第一次复查右眼视力")
    private String fcDate11;

    @ApiModelProperty(name = "fcDate12",value = "第一次复查右眼眼压")
    private String fcDate12;

    @ApiModelProperty(name = "fcDate13",value = "第一次复查右眼角膜情况")
    private String fcDate13;

    @ApiModelProperty(name = "fcDate14",value = "第一次复查右眼角膜厚度")
    private String fcDate14;

    @ApiModelProperty(name = "fcDate15",value = "第一次复查左眼视力")
    private String fcDate15;

    @ApiModelProperty(name = "fcDate16",value = "第一次复查左眼眼压")
    private String fcDate16;

    @ApiModelProperty(name = "fcDate17",value = "第一次复查左眼角膜情况")
    private String fcDate17;

    @ApiModelProperty(name = "fcDate18",value = "第一次复查左眼角膜厚度")
    private String fcDate18;

    @ApiModelProperty(name = "fcDate2",value = "第二次复查时间")
    private String fcDate2;

    @ApiModelProperty(name = "fcDate21",value = "第二次复查右眼视力")
    private String fcDate21;

    @ApiModelProperty(name = "fcDate22",value = "第二次复查右眼眼压")
    private String fcDate22;

    @ApiModelProperty(name = "fcDate23",value = "第二次复查右眼角膜情况")
    private String fcDate23;

    @ApiModelProperty(name = "fcDate24",value = "第二次复查右眼角膜厚度")
    private String fcDate24;

    @ApiModelProperty(name = "fcDate25",value = "第二次复查左眼视力")
    private String fcDate25;

    @ApiModelProperty(name = "fcDate26",value = "第二次复查左眼眼压")
    private String fcDate26;

    @ApiModelProperty(name = "fcDate27",value = "第二次复查左眼角膜情况")
    private String fcDate27;

    @ApiModelProperty(name = "fcDate28",value = "第二次复查左眼角膜厚度")
    private String fcDate28;

    @ApiModelProperty(name = "fcDate3",value = "第三次复查时间")
    private String fcDate3;

    @ApiModelProperty(name = "fcDate31",value = "第三次复查右眼视力")
    private String fcDate31;

    @ApiModelProperty(name = "fcDate32",value = "第三次复查右眼眼压")
    private String fcDate32;

    @ApiModelProperty(name = "fcDate33",value = "第三次复查右眼角膜情况")
    private String fcDate33;

    @ApiModelProperty(name = "fcDate34",value = "第三次复查右眼角膜厚度")
    private String fcDate34;

    @ApiModelProperty(name = "fcDate35",value = "第三次复查左眼视力")
    private String fcDate35;

    @ApiModelProperty(name = "fcDate36",value = "第三次复查左眼眼压")
    private String fcDate36;

    @ApiModelProperty(name = "fcDate37",value = "第三次复查左眼角膜情况")
    private String fcDate37;

    @ApiModelProperty(name = "fcDate38",value = "第三次复查左眼角膜厚度")
    private String fcDate38;

    @ApiModelProperty(name = "fcDate4",value = "第四次复查时间")
    private String fcDate4;

    @ApiModelProperty(name = "fcDate41",value = "第四次复查右眼视力")
    private String fcDate41;

    @ApiModelProperty(name = "fcDate42",value = "第四次复查右眼眼压")
    private String fcDate42;

    @ApiModelProperty(name = "fcDate43",value = "第四次复查右眼角膜情况")
    private String fcDate43;

    @ApiModelProperty(name = "fcDate44",value = "第四次复查右眼角膜厚度")
    private String fcDate44;

    @ApiModelProperty(name = "fcDate45",value = "第四次复查左眼视力")
    private String fcDate45;

    @ApiModelProperty(name = "fcDate46",value = "第四次复查左眼眼压")
    private String fcDate46;

    @ApiModelProperty(name = "fcDate47",value = "第四次复查左眼角膜情况")
    private String fcDate47;

    @ApiModelProperty(name = "fcDate48",value = "第四次复查左眼角膜厚度")
    private String fcDate48;

    @ApiModelProperty(name = "fcDate5",value = "第五次复查时间")
    private String fcDate5;

    @ApiModelProperty(name = "fcDate51",value = "第五次复查右眼视力")
    private String fcDate51;

    @ApiModelProperty(name = "fcDate52",value = "第五次复查右眼眼压")
    private String fcDate52;

    @ApiModelProperty(name = "fcDate53",value = "第五次复查右眼角膜情况")
    private String fcDate53;

    @ApiModelProperty(name = "fcDate54",value = "第五次复查右眼角膜厚度")
    private String fcDate54;

    @ApiModelProperty(name = "fcDate55",value = "第五次复查左眼视力")
    private String fcDate55;

    @ApiModelProperty(name = "fcDate56",value = "第五次复查左眼眼压")
    private String fcDate56;

    @ApiModelProperty(name = "fcDate57",value = "第五次复查左眼角膜情况")
    private String fcDate57;

    @ApiModelProperty(name = "fcDate58",value = "第五次复查左眼角膜厚度")
    private String fcDate58;

    @ApiModelProperty(name = "fcDate6",value = "第六次复查时间")
    private String fcDate6;

    @ApiModelProperty(name = "fcDate61",value = "第六次复查右眼视力")
    private String fcDate61;

    @ApiModelProperty(name = "fcDate62",value = "第六次复查右眼眼压")
    private String fcDate62;

    @ApiModelProperty(name = "fcDate63",value = "第六次复查右眼角膜情况")
    private String fcDate63;

    @ApiModelProperty(name = "fcDate64",value = "第六次复查右眼角膜厚度")
    private String fcDate64;

    @ApiModelProperty(name = "fcDate65",value = "第六次复查左眼视力")
    private String fcDate65;

    @ApiModelProperty(name = "fcDate66",value = "第六次复查左眼眼压")
    private String fcDate66;

    @ApiModelProperty(name = "fcDate67",value = "第六次复查左眼角膜情况")
    private String fcDate67;

    @ApiModelProperty(name = "fcDate68",value = "第六次复查左眼角膜厚度")
    private String fcDate68;

    @ApiModelProperty(name = "fcDate7",value = "第七次复查时间")
    private String fcDate7;

    @ApiModelProperty(name = "fcDate71",value = "第七次复查右眼视力")
    private String fcDate71;

    @ApiModelProperty(name = "fcDate72",value = "第七次复查右眼眼压")
    private String fcDate72;

    @ApiModelProperty(name = "fcDate73",value = "第七次复查右眼角膜情况")
    private String fcDate73;

    @ApiModelProperty(name = "fcDate74",value = "第七次复查右眼角膜厚度")
    private String fcDate74;

    @ApiModelProperty(name = "fcDate75",value = "第七次复查左眼视力")
    private String fcDate75;

    @ApiModelProperty(name = "fcDate76",value = "第七次复查左眼眼压")
    private String fcDate76;

    @ApiModelProperty(name = "fcDate77",value = "第七次复查左眼角膜情况")
    private String fcDate77;

    @ApiModelProperty(name = "fcDate78",value = "第七次复查左眼角膜厚度")
    private String fcDate78;

    @ApiModelProperty(name = "fcDate8",value = "第八次复查时间")
    private String fcDate8;

    @ApiModelProperty(name = "fcDate81",value = "第八次复查右眼视力")
    private String fcDate81;

    @ApiModelProperty(name = "fcDate82",value = "第八次复查右眼眼压")
    private String fcDate82;

    @ApiModelProperty(name = "fcDate83",value = "第八次复查右眼角膜情况")
    private String fcDate83;

    @ApiModelProperty(name = "fcDate84",value = "第八次复查右眼角膜厚度")
    private String fcDate84;

    @ApiModelProperty(name = "fcDate85",value = "第八次复查左眼视力")
    private String fcDate85;

    @ApiModelProperty(name = "fcDate86",value = "第八次复查左眼眼压")
    private String fcDate86;

    @ApiModelProperty(name = "fcDate87",value = "第八次复查左眼角膜情况")
    private String fcDate87;

    @ApiModelProperty(name = "fcDate88",value = "第八次复查左眼角膜厚度")
    private String fcDate88;

    @ApiModelProperty(name = "fcDate9",value = "第九次复查时间")
    private String fcDate9;

    @ApiModelProperty(name = "fcDate91",value = "第九次复查右眼视力")
    private String fcDate91;

    @ApiModelProperty(name = "fcDate92",value = "第九次复查右眼眼压")
    private String fcDate92;

    @ApiModelProperty(name = "fcDate93",value = "第九次复查右眼角膜情况")
    private String fcDate93;

    @ApiModelProperty(name = "fcDate94",value = "第九次复查右眼角膜厚度")
    private String fcDate94;

    @ApiModelProperty(name = "fcDate95",value = "第九次复查左眼视力")
    private String fcDate95;

    @ApiModelProperty(name = "fcDate96",value = "第九次复查左眼眼压")
    private String fcDate96;

    @ApiModelProperty(name = "fcDate97",value = "第九次复查左眼角膜情况")
    private String fcDate97;

    @ApiModelProperty(name = "fcDate98",value = "第九次复查左眼角膜厚度")
    private String fcDate98;

    @ApiModelProperty(name = "fcDate10",value = "第十次复查时间")
    private String fcDate10;

    @ApiModelProperty(name = "fcDate101",value = "第十次复查右眼视力")
    private String fcDate101;

    @ApiModelProperty(name = "fcDate102",value = "第十次复查右眼眼压")
    private String fcDate102;

    @ApiModelProperty(name = "fcDate103",value = "第十次复查右眼角膜情况")
    private String fcDate103;

    @ApiModelProperty(name = "fcDate104",value = "第十次复查右眼角膜厚度")
    private String fcDate104;

    @ApiModelProperty(name = "fcDate105",value = "第十次复查左眼视力")
    private String fcDate105;

    @ApiModelProperty(name = "fcDate106",value = "第十次复查左眼眼压")
    private String fcDate106;

    @ApiModelProperty(name = "fcDate107",value = "第十次复查左眼角膜情况")
    private String fcDate107;

    @ApiModelProperty(name = "fcDate108",value = "第十次复查左眼角膜厚度")
    private String fcDate108;

    @ApiModelProperty(name = "createTime",value = "创建时间")
    private Date createTime;

}

==> customized-facade-1.0.7-20210628.075422-14-sources.jar: com/bizvane/customized/facade/models/vo/MemberCaseDetailVo.java <==
package com.bizvane.customized.facade.models.vo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Date;

@Data
public class MemberCaseDetailVo {

    @ApiModelProperty(name = "Id", value = "病历ID")
    private Long id;

    @ApiModelProperty(name = "name",value = "姓名")
    private String name;

    @ApiModelProperty(name = "phone",value = "手机号")
    private String phone;

    @ApiModelProperty(name = "sex",value = "性别")
    private String sex;

    @ApiModelProperty(name = "age",value = "年龄")
    private String age;

    @ApiModelProperty(name = "card",value = "身份证")
    private String card;

    @ApiModelProperty(name = "job",value = "职业")
    private String job;

    @ApiModelProperty(name = "addr",value = "地址")
    private String addr;

    @ApiModelProperty(name = "rightEyeVision",value = "右眼戴镜视力")
    private String rightEyeVision;

    @ApiModelProperty(name = "leftEyeVision",value = "左眼戴镜视力")
    private String leftEyeVision;

    @ApiModelProperty(name = "rightLyEyeVisionJ",value = "右眼裸眼视力近")
    private String rightLyEyeVisionJ;

    @ApiModelProperty(name = "rightLyEyeVisionY",value = "右眼裸眼视力远")
    private String rightLyEyeVisionY;

    @ApiModelProperty(name = "leftLyEyeVisionJ",value = "左眼裸眼视力近")
    private String leftLyEyeVisionJ;

    @ApiModelProperty(name = "leftLyEyeVisionY",value = "左眼裸眼视力远")
    private String leftLyEyeVisionY;

    @ApiModelProperty(name = "rightEyePressure",value = "右眼眼压")
    private String rightEyePressure;

    @ApiModelProperty(name = "leftEyePressure",value = "左眼眼压")
    private String leftEyePressure;

    @ApiModelProperty(name = "rightPupilDiameterPhotopic",value = "右眼瞳孔直径明视")
    private String rightPupilDiameterPhotopic;

    @ApiModelProperty(name = "leftPupilDiameterPhotopic",value = "左眼瞳孔直径明视")
    private String leftPupilDiameterPhotopic;

    @ApiModelProperty(name = "rightPupilDiameterAmblyopia",value = "右眼瞳孔直径暗视")
    private String rightPupilDiameterAmblyopia;

    @ApiModelProperty(name = "leftPupilDiameterAmblyopia",value = "左眼瞳孔直径暗视")
    private String leftPupilDiameterAmblyopia;

    @ApiModelProperty(name = "rightEyePosition",value = "右眼眼位")
    private String rightEyePosition;

    @ApiModelProperty(name = "rightEyePositionValue",value = "右眼眼位数值")
    private String rightEyePositionValue;

    @ApiModelProperty(name = "leftEyePosition",value = "左眼眼位")
    private String leftEyePosition;

    @ApiModelProperty(name = "leftEyePositionValue",value = "左眼眼位数值")
    private String leftEyePositionValue;

    @ApiModelProperty(name = "rightEyeDiopterDs",value = "右眼复光度数DS")
    private String rightEyeDiopterDs;

    @ApiModelProperty(name = "rightEyeDiopterDc",value = "右眼复光度数DC")
    private String rightEyeDiopterDc;

    @ApiModelProperty(name = "rightEyeComplexPowerAxis",value = "右眼复光度数轴位")
    private String rightEyeComplexPowerAxis;

    @ApiModelProperty(name = "rightEyeDiopterCorrectedVisualAcuity",value = "右眼复光度数矫正视力")
    private String rightEyeDiopterCorrectedVisualAcuity;

    @ApiModelProperty(name = "leftEyeDiopterDs",value = "左眼复光度数DS")
    private String leftEyeDiopterDs;

    @ApiModelProperty(name = "leftEyeDiopterDc",value = "左眼复光度数DC")
    private String leftEyeDiopterDc;

    @ApiModelProperty(name = "leftEyeComplexPowerAxis",value = "左眼复光度数轴位")
    private String leftEyeComplexPowerAxis;

    @ApiModelProperty(name = "leftEyeDiopterCorrectedVisualAcuity",value = "左眼复光度数矫正视力")
    private String leftEyeDiopterCorrectedVisualAcuity;

    @ApiModelProperty(name = "rightEyeCt",value = "右眼术前角膜厚度")
    private String rightEyeCt;

    @ApiModelProperty(name = "leftEyeCt",value = "左眼术前角膜厚度")
    private String leftEyeCt;

    @ApiModelProperty(name = "rightEyeDegrees",value = "右眼验光度数")
    private String rightEyeDegrees;

    @ApiModelProperty(name = "leftEyeDegrees",value = "左眼验光度数")
    private String leftEyeDegrees;

    @ApiModelProperty(name = "rightEyeK1",value = "右眼角膜曲率K1")
    private String rightEyeK1;

    @ApiModelProperty(name = "rightEyeZwK1",value = "右眼角膜曲率K1轴位")
    private String rightEyeZwK1;

    @ApiModelProperty(name = "leftEyeK1",value = "左眼角膜曲率K1")
    private String leftEyeK1;

    @ApiModelProperty(name = "leftEyeZwK1",value = "左眼角膜曲率K1轴位")
    private String leftEyeZwK1;

    @ApiModelProperty(name = "rightEyeK2",value = "右眼角膜曲率K2")
    private String rightEyeK2;

    @ApiModelProperty(name = "rightEyeZwK2",value = "右眼角膜曲率K2轴位")
    private String rightEyeZwK2;

    @ApiModelProperty(name = "leftEyeK2",value = "左眼角膜曲率K2")
    private String leftEyeK2;

    @ApiModelProperty(name = "leftEyeZwK2",value = "左眼角膜曲率K2轴位")
    private String leftEyeZwK2;

    @ApiModelProperty(name = "rightEyeSurgery",value = "右眼手术方式")
    private String rightEyeSurgery;

    @ApiModelProperty(name = "leftEyeSurgery",value = "左眼手术方式")
    private String leftEyeSurgery;

    @ApiModelProperty(name = "rightEyeSsDate",value = "右眼手术日期")
    private String rightEyeSsDate;

    @ApiModelProperty(name = "leftEyeSsDate",value = "左眼手术日期")
    private String leftEyeSsDate;

    @ApiModelProperty(name = "fcDate1",value = "第一次复查时间")
    private String fcDate1;

    @ApiModelProperty(name = "fcDate11",value = "第一次复查右眼视力")
    private String fcDate11;

    @ApiModelProperty(name = "fcDate12",value = "第一次复查右眼眼压")
    private String fcDate12;

    @ApiModelProperty(name = "fcDate13",value = "第一次复查右眼角膜情况")
    private String fcDate13;

    @ApiModelProperty(name = "fcDate14",value = "第一次复查右眼角膜厚度")
    private String fcDate14;

    @ApiModelProperty(name = "fcDate15",value = "第一次复查左眼视力")
    private String fcDate15;

    @ApiModelProperty(name = "fcDate16",value = "第一次复查左眼眼压")
    private String fcDate16;

    @ApiModelProperty(name = "fcDate17",value = "第一次复查左眼角膜情况")
    private String fcDate17;

    @ApiModelProperty(name = "fcDate18",value = "第一次复查左眼角膜厚度")
    private String fcDate18;

    @ApiModelProperty(name = "fcDate2",value = "第二次复查时间")
    private String fcDate2;

    @ApiModelProperty(name = "fcDate21",value = "第二次复查右眼视力")
    private String fcDate21;

    @ApiModelProperty(name = "fcDate22",value = "第二次复查右眼眼压")
    private String fcDate22;

    @ApiModelProperty(name = "fcDate23",value = "第二次复查右眼角膜情况")
    private String fcDate23;

    @ApiModelProperty(name = "fcDate24",value = "第二次复查右眼角膜厚度")
    private String fcDate24;

    @ApiModelProperty(name = "fcDate25",value = "第二次复查左眼视力")
    private String fcDate25;

    @ApiModelProperty(name = "fcDate26",value = "第二次复查左眼眼压")
    private String fcDate26;

    @ApiModelProperty(name = "fcDate27",value = "第二次复查左眼角膜情况")
    private String fcDate27;

    @ApiModelProperty(name = "fcDate28",value = "第二次复查左眼角膜厚度")
    private String fcDate28;

    @ApiModelProperty(name = "fcDate3",value = "第三次复查时间")
    private String fcDate3;

    @ApiModelProperty(name = "fcDate31",value = "第三次复查右眼视力")
    private String fcDate31;

    @ApiModelProperty(name = "fcDate32",value = "第三次复查右眼眼压")
    private String fcDate32;

    @ApiModelProperty(name = "fcDate33",value = "第三次复查右眼角膜情况")
    private String fcDate33;

    @ApiModelProperty(name = "fcDate34",value = "第三次复查右眼角膜厚度")
    private String fcDate34;

    @ApiModelProperty(name = "fcDate35",value = "第三次复查左眼视力")
    private String fcDate35;

    @ApiModelProperty(name = "fcDate36",value = "第三次复查左眼眼压")
    private String fcDate36;

    @ApiModelProperty(name = "fcDate37",value = "第三次复查左眼角膜情况")
    private String fcDate37;

    @ApiModelProperty(name = "fcDate38",value = "第三次复查左眼角膜厚度")
    private String fcDate38;

    @ApiModelProperty(name = "fcDate4",value = "第四次复查时间")
    private String fcDate4;

    @ApiModelProperty(name = "fcDate41",value = "第四次复查右眼视力")
    private String fcDate41;

    @ApiModelProperty(name = "fcDate42",value = "第四次复查右眼眼压")
    private String fcDate42;

    @ApiModelProperty(name = "fcDate43",value = "第四次复查右眼角膜情况")
    private String fcDate43;

    @ApiModelProperty(name = "fcDate44",value = "第四次复查右眼角膜厚度")
    private String fcDate44;

    @ApiModelProperty(name = "fcDate45",value = "第四次复查左眼视力")
    private String fcDate45;

    @ApiModelProperty(name = "fcDate46",value = "第四次复查左眼眼压")
    private String fcDate46;

    @ApiModelProperty(name = "fcDate47",value = "第四次复查左眼角膜情况")
    private String fcDate47;

    @ApiModelProperty(name = "fcDate48",value = "第四次复查左眼角膜厚度")
    private String fcDate48;

    @ApiModelProperty(name = "fcDate5",value = "第五次复查时间")
    private String fcDate5;

    @ApiModelProperty(name = "fcDate51",value = "第五次复查右眼视力")
    private String fcDate51;

    @ApiModelProperty(name = "fcDate52",value = "第五次复查右眼眼压")
    private String fcDate52;

    @ApiModelProperty(name = "fcDate53",value = "第五次复查右眼角膜情况")
    private String fcDate53;

    @ApiModelProperty(name = "fcDate54",value = "第五次复查右眼角膜厚度")
    private String fcDate54;

    @ApiModelProperty(name = "fcDate55",value = "第五次复查左眼视力")
    private String fcDate55;

    @ApiModelProperty(name = "fcDate56",value = "第五次复查左眼眼压")
    private String fcDate56;

    @ApiModelProperty(name = "fcDate57",value = "第五次复查左眼角膜情况")
    private String fcDate57;

    @ApiModelProperty(name = "fcDate58",value = "第五次复查左眼角膜厚度")
    private String fcDate58;

    @ApiModelProperty(name = "fcDate6",value = "第六次复查时间")
    private String fcDate6;

    @ApiModelProperty(name = "fcDate61",value = "第六次复查右眼视力")
    private String fcDate61;

    @ApiModelProperty(name = "fcDate62",value = "第六次复查右眼眼压")
    private String fcDate62;

    @ApiModelProperty(name = "fcDate63",value = "第六次复查右眼角膜情况")
    private String fcDate63;

    @ApiModelProperty(name = "fcDate64",value = "第六次复查右眼角膜厚度")
    private String fcDate64;

    @ApiModelProperty(name = "fcDate65",value = "第六次复查左眼视力")
    private String fcDate65;

    @ApiModelProperty(name = "fcDate66",value = "第六次复查左眼眼压")
    private String fcDate66;

    @ApiModelProperty(name = "fcDate67",value = "第六次复查左眼角膜情况")
    private String fcDate67;

    @ApiModelProperty(name = "fcDate68",value = "第六次复查左眼角膜厚度")
    private String fcDate68;

    @ApiModelProperty(name = "fcDate7",value = "第七次复查时间")
    private String fcDate7;

    @ApiModelProperty(name = "fcDate71",value = "第七次复查右眼视力")
    private String fcDate71;

    @ApiModelProperty(name = "fcDate72",value = "第七次复查右眼眼压")
    private String fcDate72;

    @ApiModelProperty(name = "fcDate73",value = "第七次复查右眼角膜情况")
    private String fcDate73;

    @ApiModelProperty(name = "fcDate74",value = "第七次复查右眼角膜厚度")
    private String fcDate74;

    @ApiModelProperty(name = "fcDate75",value = "第七次复查左眼视力")
    private String fcDate75;

    @ApiModelProperty(name = "fcDate76",value = "第七次复查左眼眼压")
    private String fcDate76;

    @ApiModelProperty(name = "fcDate77",value = "第七次复查左眼角膜情况")
    private String fcDate77;

    @ApiModelProperty(name = "fcDate78",value = "第七次复查左眼角膜厚度")
    private String fcDate78;

    @ApiModelProperty(name = "fcDate8",value = "第八次复查时间")
    private String fcDate8;

    @ApiModelProperty(name = "fcDate81",value = "第八次复查右眼视力")
    private String fcDate81;

    @ApiModelProperty(name = "fcDate82",value = "第八次复查右眼眼压")
    private String fcDate82;

    @ApiModelProperty(name = "fcDate83",value = "第八次复查右眼角膜情况")
    private String fcDate83;

    @ApiModelProperty(name = "fcDate84",value = "第八次复查右眼角膜厚度")
    private String fcDate84;

    @ApiModelProperty(name = "fcDate85",value = "第八次复查左眼视力")
    private String fcDate85;

    @ApiModelProperty(name = "fcDate86",value = "第八次复查左眼眼压")
    private String fcDate86;

    @ApiModelProperty(name = "fcDate87",value = "第八次复查左眼角膜情况")
    private String fcDate87;

    @ApiModelProperty(name = "fcDate88",value = "第八次复查左眼角膜厚度")
    private String fcDate88;

    @ApiModelProperty(name = "fcDate9",value = "第九次复查时间")
    private String fcDate9;

    @ApiModelProperty(name = "fcDate91",value = "第九次复查右眼视力")
    private String fcDate91;

    @ApiModelProperty(name = "fcDate92",value = "第九次复查右眼眼压")
    private String fcDate92;

    @ApiModelProperty(name = "fcDate93",value = "第九次复查右眼角膜情况")
    private String fcDate93;

    @ApiModelProperty(name = "fcDate94",value = "第九次复查右眼角膜厚度")
    private String fcDate94;

    @ApiModelProperty(name = "fcDate95",value = "第九次复查左眼视力")
    private String fcDate95;

    @ApiModelProperty(name = "fcDate96",value = "第九次复查左眼眼压")
    private String fcDate96;

    @ApiModelProperty(name = "fcDate97",value = "第九次复查左眼角膜情况")
    private String fcDate97;

    @ApiModelProperty(name = "fcDate98",value = "第九次复查左眼角膜厚度")
    private String fcDate98;

    @ApiModelProperty(name = "fcDate10",value = "第十次复查时间")
    private String fcDate10;

    @ApiModelProperty(name = "fcDate101",value = "第十次复查右眼视力")
    private String fcDate101;

    @ApiModelProperty(name = "fcDate102",value = "第十次复查右眼眼压")
    private String fcDate102;

    @ApiModelProperty(name = "fcDate103",value = "第十次复查右眼角膜情况")
    private String fcDate103;

    @ApiModelProperty(name = "fcDate104",value = "第十次复查右眼角膜厚度")
    private String fcDate104;

    @ApiModelProperty(name = "fcDate105",value = "第十次复查左眼视力")
    private String fcDate105;

    @ApiModelProperty(name = "fcDate106",value = "第十次复查左眼眼压")
    private String fcDate106;

    @ApiModelProperty(name = "fcDate107",value = "第十次复查左眼角膜情况")
    private String fcDate107;

    @ApiModelProperty(name = "fcDate108",value = "第十次复查左眼角膜厚度")
    private String fcDate108;

    @ApiModelProperty(name = "createTime",value = "创建时间")
    private Date createTime;

}
